#ifndef NT2_INCLUDE_FUNCTIONS_BITWISE_NOTAND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITWISE_NOTAND_HPP_INCLUDED

#include <nt2/bitwise/include/functions/bitwise_notand.hpp>

#endif
